@@ -26,4 +26,20 @@ def wrap_helpers(localdict):
         localdict[name] = helper_wrapper(func)
 
 wrap_helpers(locals())
-'''
\ No newline at end of file
+'''
+
+try:
+    import pytz
+except:
+    pytz = None
+    
+_tz_cache = {}
+    
+def strftime(value, fmt, tzname=None):
+    global _tz_cache
+    if isinstance(tzname, basestring):
+        if tzname not in _tz_cache.keys():
+            _tz_cache[tzname] = pytz.timezone(tzname)
+        tz = _tz_cache[tzname]
+        value = value.replace(tzinfo=pytz.utc).astimezone(tz)  
+    return value.strftime(fmt)
\ No newline at end of file
