@@ -4,13 +4,13 @@
 ## All rights reserved                     ##
 #############################################
 
-import pyxer.utils.jsonhelper
+# import pyxer.utils.jsonhelper
 import os
 import os.path
 import sys
 import types
 import logging
-log = logging.getLogger(__file__)
+log = logging.getLogger(__name__)
 
 try:
     import subprocess
@@ -30,16 +30,61 @@ class Dict(dict):
     def __setattr__(self, name, value):
         self[name] = value
 
+class AttrDict(dict):
+
+    # __slots__ ?
+
+    def __init__(self, dict=None, **kwargs):
+        if dict is None:
+            dict = kwargs
+        for k, v in dict.items():
+            self[k] = v
+
+    def __getattr__(self, name):
+        try:
+            return dict.__getattr__(self, name)
+        except:
+            return self.get(name, None)
+
+    def __setattr__(self, name, value):
+        if (isinstance(value, dict)) and (not isinstance(value, AttrDict)):
+            value = AttrDict(value)
+        dict.__setitem__(self, name, value)
+
+    def __delattr__(self, name):
+        del self[name]
+
+    __setitem__ = __setattr__
+
+    def __getnext__(self, name, full):
+        try:
+            if "." in name:
+                left, right = name.split(".", 1)
+                value = self.__getnext__(left, full)
+                return value[right]
+            else:
+                return dict.__getitem__(self, name)
+        except:
+            raise KeyError, full
+
+    def __getitem__(self, name):
+        try:
+            return dict.__getitem__(self, name)
+        except:
+            return self.__getnext__(name, name)
+
 def html_escape(value):
     return (value
         .replace("&", "&amp;")
         .replace('"', "&quot;")
+        .replace("'", "&apos;")
         .replace('<', "&lt;")
         .replace('>', "&gt;"))
 
 def html_unescape(value):
     return (value
         .replace("&quot;", '"')
+        .replace("&apos;", "'")
         .replace("&lt;", '<')
         .replace("&gt;", '>')
         .replace("&amp;", '&'))
@@ -184,3 +229,42 @@ def call_script(cmd, root=None, cwd=None):
 
 call_bin = call_script
 
+def copy_python(src, dst, symlinks = False):
+    " Copies just Python source files "
+    import shutil
+    names = os.listdir(src)
+    try:
+        os.makedirs(dst)
+    except:
+        pass
+    errors = []
+    for name in names:
+        srcname = os.path.join(src, name)
+        dstname = os.path.join(dst, name)
+        try:
+            if symlinks and os.path.islink(srcname):
+                linkto = os.readlink(srcname)
+                os.symlink(linkto, dstname)
+            elif os.path.isdir(srcname):
+                if not name.startswith("."):
+                    copy_python(srcname, dstname, symlinks)
+            else:
+                if name.endswith(".py"):
+                    print "create", dstname
+                    shutil.copy2(srcname, dstname)
+            # XXX What about devices, sockets etc.?
+        except (IOError, os.error), why:
+            errors.append((srcname, dstname, str(why)))
+        # catch the Error from the recursive copytree so that we can
+        # continue with other files
+        except Error, err:
+            errors.extend(err.args[0])
+    try:
+        shutil.copystat(src, dst)
+    except WindowsError:
+        # can't copy file access times on Windows
+        pass
+    except OSError, why:
+        errors.extend((src, dst, str(why)))
+    if errors:
+        raise shutil.Error, errors
